@@ -1,3 +1,4 @@
+import json
 import re
 import tempfile
 import uuid
@@ -8,6 +9,7 @@ from django.core.files.uploadedfile import SimpleUploadedFile, UploadedFile
 from django.http import StreamingHttpResponse
 from django.http.cookie import SimpleCookie
 from django.utils import timezone
+import six
 
 from wiretap.models import Message, Tap
 from wiretap.signals import post_save_message_request, post_save_message_response
@@ -47,7 +49,7 @@ class WiretapMiddleware(object):
     def process_request(self, request):
         """
         Process incoming requests. If we're tracking this request, we'll store
-        a created `Message` object in `request._wiretap_message`.
+        a created `Message` object in `request.wiretap_message`.
         """
 
         request.wiretap_message = None
@@ -59,12 +61,12 @@ class WiretapMiddleware(object):
 
         req_content_type = None
         req_headers = []
-        for (key, value) in request.META.iteritems():
+        for (key, value) in six.iteritems(request.META):
             if key.startswith('HTTP_'):
                 key = key[5:].title()
                 req_headers.append((key, value))
                 if key == 'Content-Type':
-                    content_type = value
+                    req_content_type = value
 
         if not request.body:
             req_body_file = None
@@ -81,7 +83,7 @@ class WiretapMiddleware(object):
             remote_addr=request.META['REMOTE_ADDR'],
             req_method=request.method,
             req_path=request.path,
-            req_headers=req_headers,
+            req_headers_json=json.dumps(req_headers),
             req_body=req_body_file
         )
 
@@ -94,7 +96,7 @@ class WiretapMiddleware(object):
     def process_response(self, request, response):
         """
         Process the response. If we're tracking this request,
-        `request._wiretap_message` will be set.
+        `request.wiretap_message` will be set.
         """
 
         if not request.wiretap_message:
@@ -108,8 +110,8 @@ class WiretapMiddleware(object):
 
 class WiretapHttpResponse(StreamingHttpResponse):
     """
-    HttpResponse that mimics another response, and saves the data to a
-    `Message` object.
+    HttpResponse that wraps another response, mimicking it and saving the data
+    to a `Message` object.
     """
 
     def __init__(self, request, response, message):
@@ -124,12 +126,14 @@ class WiretapHttpResponse(StreamingHttpResponse):
         Copy data from the original response.
         """
 
+        for key, _ in self.items():
+            del self[key]
+
+        for key, value in response.items():
+            self[key] = value
+
         self.status_code = response.status_code
         self.reason_phrase = response.reason_phrase
-        self._headers = {
-            key.lower(): (key, value,)
-            for (key, value) in response.items()
-        }
         self.cookies = SimpleCookie(str(response.cookies))
 
     def __iter__(self):
@@ -150,18 +154,18 @@ class WiretapHttpResponse(StreamingHttpResponse):
 
             self._message.res_status_code = self._response.status_code
             self._message.res_reason_phrase = self._response.reason_phrase
-            self._message.res_headers = self._response.items()
+            self._message.res_headers_json = json.dumps(self._response.items())
             self._message.res_body = res_body_file
             self._message.save()
 
-            post_save_message_response.send(
-                sender=self.__class__,
-                request=self._request,
-                response=self._response,
-                message=self._message
-            )
+        post_save_message_response.send(
+            sender=self.__class__,
+            request=self._request,
+            response=self._response,
+            message=self._message
+        )
 
-            delete_old_messages()
+        delete_old_messages()
 
 def delete_old_messages():
     """
